@@ -56,6 +56,7 @@ use Net::Nmsg::Handle;
 
 use constant HANDLE_IO => 'Net::Nmsg::Handle';
 use constant OUTPUT_XS => 'Net::Nmsg::XS::output';
+use constant RATE_XS   => 'Net::Nmsg::XS::rate';
 
 my %Defaults = (
 
@@ -111,12 +112,13 @@ sub set_rate {
   else {
     ($rate, $freq) = @_;
   }
-  $self->_set_xs_opt(rate => $rate, $freq)
+  $self->_set_xs_opt(rate => RATE_XS->init($rate, $freq))
 }
 
 ###
 
 sub is_file { (shift->_xs || return)->is_file }
+sub is_json { (shift->_xs || return)->is_json }
 sub is_sock { (shift->_xs || return)->is_sock }
 sub is_pres { (shift->_xs || return)->is_pres }
 sub is_cb   { (shift->_xs || return)->is_cb   }
@@ -183,6 +185,17 @@ sub open_file {
   $self->_init_output($spec, $io, $xs, %opt);
 }
 
+sub open_json {
+  my($self, $spec, $fatal, %opt) = shift->_open_init(@_);
+  my $io;
+  eval { $io = $self->HANDLE_IO->open_output_file($spec, %opt) };
+  $@ && $self->error($@) && ($fatal ? croak $self->error : return);
+  my $xs;
+  eval { $xs = $self->OUTPUT_XS->open_json($io) };
+  $@ && $self->error($@) && ($fatal ? croak $self->error : return);
+  $self->_init_output($spec, $io, $xs, %opt);
+}
+
 sub open_sock {
   my $self = shift;
   my $spec = @_ % 2 ? shift : join('/', splice(@_, 0, 2));
@@ -334,7 +347,11 @@ Set the line ending character for presentation outputs.
 
 =item open_file($spec, %options)
 
-Opens an output in nmsg format, as specified by file name, or file handle.
+Opens an output in nmsg format, as specified by file name or file handle.
+
+=item open_json($spec, %options)
+
+Opens an output in JSON format, as specified by file name or file handle.
 
 =item open_sock($spec, %options)
 
